@@ -8,7 +8,6 @@ import daiquiri
 import typer
 
 from dbnomics_data_model.storage.adapters.filesystem import FileSystemStorage
-from dbnomics_data_model.storage.storage import update_strategies
 
 app = typer.Typer()
 logger = logging.getLogger(__name__)
@@ -36,14 +35,6 @@ def main(
         [("dbnomics_data_model", logging.DEBUG if debug else logging.INFO if verbose else logging.WARNING)]
     )
 
-    if dataset_update_strategy not in update_strategies:
-        logger.error(
-            "Unsupported dataset update strategy %r (supported strategies: %r)",
-            dataset_update_strategy,
-            update_strategies,
-        )
-        raise typer.Abort()
-
     dest_storage = FileSystemStorage(dest_storage_dir)
     src_storage = FileSystemStorage(src_storage_dir)
     dest_storage.update(
