@@ -511,6 +511,8 @@ class Storage(abc.ABC):
         Update provider metadata, category tree, releases metadata,
         and for all datasets: their metadata and series with metadata and observations.
         """
+        if category_tree_update_strategy not in update_strategies:
+            raise ValueError(category_tree_update_strategy)
         if dataset_update_strategy not in update_strategies:
             raise ValueError(dataset_update_strategy)
 
